@@ -16,9 +16,19 @@ __all__ = ['parse_p12']
 
 
 def parse_p12(p12_path, passphrase, directory):
+    """
+        :param p12_path: The path to the p12 file
+        :param passphrase: The password to open the p12 file
+        :param directory: The path where the p12 will be extracted
+    """
     with open(p12_path, 'rb') as f:
         c = f.read()
 
+    try:
+        passphrase.decode(encoding='UTF-8')
+    except:
+        passphrase = passphrase.encode(encoding='UTF-8')
+
     p = load_pkcs12(c, passphrase)
     certificate = p.get_certificate()
     private_key = p.get_privatekey()
