@@ -11,7 +11,7 @@ from os import path, makedirs
 import urllib.request as request
 import http.client, json
 
-from sightcall_auth.config import directory
+from sightcall_auth.config import directory as default_cert_dir
 
 __all__ = ['Auth']
 
@@ -43,14 +43,16 @@ class Auth():
     client_id = None
     client_secret = None
     url = None
+    directory = None
 
-    def __init__(self, client_id, client_secret, url):
+    def __init__(self, client_id, client_secret, url, cert_directory=directory):
         self.client_id = client_id
         self.client_secret = client_secret
         self.url = url
+        self.directory = cert_directory
 
     def connect(self, uid):
-        https_con = HTTPSClientAuthHandler(directory + '/private_key.pem', directory + '/cert.pem')
+        https_con = HTTPSClientAuthHandler(self.directory + '/private_key.pem', self.directory + '/cert.pem')
         opener = request.build_opener(https_con)
         response = opener.open(path.join(self.url, "?client_id="+ self.client_id
                                             +"&client_secret="+ self.client_secret
